@@ -13,5 +13,5 @@ convention = {
     "pk": "pk_%(table_name)s",
 }
 
-Base = declarative_base()
-Base.metadata = MetaData(naming_convention=convention)
+metadata = MetaData(naming_convention=convention)
+Base = declarative_base(metadata=metadata)
