@@ -13,25 +13,13 @@ from .hives import Hives, HiveConditions
 from .events import Events
 
 
-class CommentTypes(Base):
-    __tablename__ = "comment_types"
-    id = Column(UUID(as_uuid=True), primary_key=True, default=uuid.uuid4)
-    name = Column(TEXT(), nullable=False)
-
-    created_at = Column(TIMESTAMP(), default=datetime.datetime.utcnow)
-    updated_at = Column(
-        TIMESTAMP(), default=datetime.datetime.utcnow, onupdate=datetime.datetime.utcnow
-    )
-    deleted_at = Column(TIMESTAMP(), nullable=True)
-
-
 class Comments(Base):
     __tablename__ = "comments"
     id = Column(UUID(as_uuid=True), primary_key=True, default=uuid.uuid4)
     comment = Column(TEXT(), nullable=False)
     date = Column(TIMESTAMP(), nullable=False)
+    type = Column(TEXT(), nullable=False)
     user_id = Column(UUID(as_uuid=True), ForeignKey(Users.id), nullable=False)
-    type_id = Column(UUID(as_uuid=True), ForeignKey(CommentTypes.id), nullable=False)
     swarm_id = Column(UUID(as_uuid=True), ForeignKey(Swarms.id), nullable=True)
     hive_id = Column(UUID(as_uuid=True), ForeignKey(Hives.id), nullable=True)
     event_id = Column(UUID(as_uuid=True), ForeignKey(Events.id), nullable=True)
@@ -43,12 +31,13 @@ class Comments(Base):
     deleted_at = Column(TIMESTAMP(), nullable=True)
 
     user = relationship(Users, backref="comments")
-    type = relationship(CommentTypes)
     swarm = relationship(Swarms, backref="comments")
     hive = relationship(Hives, backref="comments")
     event = relationship(Events, backref=backref("comment", uselist=False))
 
-func = DDL("""
+
+func = DDL(
+    """
     CREATE FUNCTION check_user_comments() RETURNS trigger AS $check_user_comments$
         BEGIN
             IF new.event_id IS NOT NULL AND NEW.user_id NOT IN (SELECT t.user_id FROM events as t WHERE t.id = NEW.event_id) THEN
@@ -65,12 +54,17 @@ func = DDL("""
 
             RETURN NEW;
         END; $check_user_comments$ LANGUAGE PLPGSQL
-""")
+"""
+)
 
-trigger = DDL("""
+trigger = DDL(
+    """
     CREATE TRIGGER trigger_user_comments BEFORE INSERT OR UPDATE ON comments
         FOR EACH ROW EXECUTE PROCEDURE check_user_comments();
-""")
+"""
+)
 
 event.listen(Comments.metadata, "after_create", func.execute_if(dialect="postgresql"))
-event.listen(Comments.metadata, "after_create", trigger.execute_if(dialect="postgresql"))
\ No newline at end of file
+event.listen(
+    Comments.metadata, "after_create", trigger.execute_if(dialect="postgresql")
+)
