@@ -24,18 +24,24 @@ class AppClient:
     def add_cors_middleware(
         self,
         allow_origins=None,
+        allow_origin_regex=None,
         allow_methods=None,
         allow_headers=None,
         allow_credentials=False,
     ):
-        self.app.add_middleware(
-            CORSMiddleware,
-            allow_origins=allow_origins or ["*"],
+        params = dict(
             allow_methods=allow_methods or ["*"],
             allow_headers=allow_headers or ["*"],
             allow_credentials=allow_credentials,
         )
 
+        if allow_origin_regex:
+            params["allow_origin_regex"] = allow_origin_regex
+        else:
+            params["allow_origins"] = allow_origins or ["*"]
+
+        self.app.add_middleware(CORSMiddleware, **params)
+
     def get_app(self):
         self._add_middleware()
         return self.app
